@@ -88,7 +88,6 @@ class ChatFunctionPage(Gtk.Box, SignalManager):
             wrap=True,
             wrap_mode=Pango.WrapMode.WORD,
         )
-        self._subheading.add_css_class("small-label")
         self._subheading.add_css_class("pb-18")
         self.append(self._subheading)
 
@@ -291,6 +290,7 @@ class ChatFunctionPage(Gtk.Box, SignalManager):
                 return
 
             self._send_files(self._widget.get_catalog())
+            app.window.activate_action("win.input-focus")
 
         elif self._mode == FunctionMode.CHANGE_NICKNAME:
             assert isinstance(self._widget, InputWidget)
