@@ -22,6 +22,7 @@ from gajim.common.i18n import _
 from gajim.common.i18n import is_rtl_text
 from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.modules.contacts import GroupchatParticipant
+from gajim.common.open_graph_parser import OpenGraphData
 from gajim.common.storage.archive import models as mod
 from gajim.common.storage.archive.const import ChatDirection
 from gajim.common.storage.archive.const import MessageState
@@ -50,6 +51,7 @@ from gajim.gtk.preview.open_graph import OpenGraphPreviewWidget
 from gajim.gtk.preview.preview import PreviewWidget
 from gajim.gtk.referenced_message import ReferencedMessageNotFoundWidget
 from gajim.gtk.referenced_message import ReferencedMessageWidget
+from gajim.gtk.util.misc import check_finalize
 from gajim.gtk.util.misc import container_remove_all
 from gajim.gtk.util.misc import get_avatar_for_message
 from gajim.gtk.util.misc import get_contact_name_for_message
@@ -110,9 +112,6 @@ class MessageRow(BaseRow):
 
         self._redraw_content()
 
-    def do_unroot(self) -> None:
-        BaseRow.do_unroot(self)
-
     @classmethod
     def from_db_row(cls, contact: ChatContactT, message: Message) -> MessageRow:
         return cls(contact, message)
@@ -140,6 +139,8 @@ class MessageRow(BaseRow):
         self.remove_css_class("retracted-message")
         self.remove_css_class("gajim-mention-highlight")
 
+        check_finalize(self._meta_box, only_children=True)
+        check_finalize(self._bottom_box, only_children=True)
         container_remove_all(self._meta_box)
         container_remove_all(self._bottom_box)
 
@@ -225,7 +226,10 @@ class MessageRow(BaseRow):
                 halign=Gtk.Align.START,
             )
             for og in message.og:
-                og_box.append(OpenGraphPreviewWidget(og))
+                og_data = OpenGraphData.from_model(og)
+                og_box.append(
+                    OpenGraphPreviewWidget(og.about, og_data=og_data, pk=og.pk)
+                )
 
             box.append(og_clamp)
 
