@@ -32,6 +32,7 @@ from gajim.common.helpers import to_user_string
 from gajim.common.modules.chat_markers import DisplayedMarkerData
 from gajim.common.modules.contacts import BareContact
 from gajim.common.modules.contacts import GroupchatContact
+from gajim.common.modules.contacts import GroupchatParticipant
 from gajim.common.modules.httpupload import HTTPFileTransfer
 from gajim.common.storage.archive.const import ChatDirection
 from gajim.common.storage.archive.const import MessageType
@@ -54,13 +55,13 @@ from gajim.gtk.conversation.rows.muc_subject import MUCSubject
 from gajim.gtk.conversation.rows.scroll_hint import ScrollHintRow
 from gajim.gtk.conversation.rows.user_status import UserStatus
 from gajim.gtk.conversation.rows.widgets import MessageRowActions
+from gajim.gtk.util.misc import check_finalize
 from gajim.gtk.util.misc import iterate_listbox_children
 
 log = logging.getLogger("gajim.gtk.conversation_view")
 
 
 class ConversationView(Gtk.ScrolledWindow):
-
     __gsignals__ = {
         "request-history": (
             GObject.SignalFlags.RUN_LAST | GObject.SignalFlags.ACTION,
@@ -151,7 +152,7 @@ class ConversationView(Gtk.ScrolledWindow):
             if isinstance(row, MessageRow):
                 timestamp_formatted = row.timestamp.strftime(format_string)
                 selection_text += (
-                    f"{timestamp_formatted} - {row.name}:\n" f"{row.get_text()}\n"
+                    f"{timestamp_formatted} - {row.name}:\n{row.get_text()}\n"
                 )
 
         self.get_clipboard().set(selection_text)
@@ -159,7 +160,6 @@ class ConversationView(Gtk.ScrolledWindow):
         self.disable_row_selection()
 
     def enable_row_selection(self, pk: int | None) -> None:
-
         self._list_box.set_selection_mode(Gtk.SelectionMode.MULTIPLE)
 
         if pk is not None:
@@ -209,6 +209,11 @@ class ConversationView(Gtk.ScrolledWindow):
         self._contact = None
         self._client = None
 
+    def reload(self) -> None:
+        if self._contact is None:
+            return
+        self.switch_contact(self._contact)
+
     def switch_contact(self, contact: ChatContactT) -> None:
         self._contact = contact
         self._client = app.get_client(contact.account)
@@ -219,7 +224,13 @@ class ConversationView(Gtk.ScrolledWindow):
 
         self.disable_row_selection()
 
-        self._load_displayed_marker()
+        if isinstance(self._contact, GroupchatParticipant):
+            show_markers = self._contact.room.settings.get("send_marker")
+        else:
+            show_markers = self._contact.settings.get("send_marker")
+
+        if show_markers:
+            self._load_displayed_marker()
 
         self._scroll_hint_row = ScrollHintRow(self._contact.account)
         self._list_box.append(self._scroll_hint_row)
@@ -258,6 +269,7 @@ class ConversationView(Gtk.ScrolledWindow):
         self._list_box.set_selection_mode(Gtk.SelectionMode.NONE)
         # Performance: Disable sort function before removing all rows
         self._list_box.set_sort_func(None)
+        check_finalize(self._list_box, only_children=True)
         self._list_box.remove_all()
 
         self._list_box.set_sort_func(self._sort_func)
@@ -336,7 +348,6 @@ class ConversationView(Gtk.ScrolledWindow):
     def _on_adj_value_changed(
         self, adj: Gtk.Adjustment, _pspec: GObject.ParamSpec
     ) -> None:
-
         if self._requesting is not None:
             return
 
@@ -491,12 +502,10 @@ class ConversationView(Gtk.ScrolledWindow):
     def add_muc_subject(
         self, subject: MucSubject, timestamp: float | None = None
     ) -> None:
-
         muc_subject = MUCSubject(self.contact.account, subject, timestamp)
         self._insert_message(muc_subject)
 
     def add_muc_user_left(self, event: events.MUCUserLeft, error: bool = False) -> None:
-
         assert isinstance(self._contact, GroupchatContact)
         if not self._contact.settings.get("print_join_left"):
             return
@@ -527,13 +536,12 @@ class ConversationView(Gtk.ScrolledWindow):
         self._insert_message(user_status)
 
     def add_info_message(self, text: str, timestamp: datetime | None = None) -> None:
-
         message = InfoMessage(self.contact.account, text, timestamp)
         self._insert_message(message)
 
     def add_file_transfer(self, transfer: HTTPFileTransfer) -> None:
         transfer_row = FileTransferRow(self.contact.account, transfer)
-        transfer_row.connect("remove", self._on_remove_row)
+        transfer_row.connect("remove", self._remove_row)
         self._insert_message(transfer_row)
 
     def add_jingle_file_transfer(
@@ -541,7 +549,6 @@ class ConversationView(Gtk.ScrolledWindow):
         event: events.FileRequestReceivedEvent | events.FileRequestSent | None = None,
         message: Message | None = None,
     ) -> None:
-
         assert isinstance(self._contact, BareContact)
         jingle_transfer_row = FileTransferJingleRow(
             self._contact.account, self._contact, event=event, message=message
@@ -700,18 +707,17 @@ class ConversationView(Gtk.ScrolledWindow):
         if occupant_id == str(ChatDirection.INCOMING):
             # Single Chat
             del self._dm_rows[current_marker.id]
-            self._list_box.remove(row)
+            self._remove_row(row)
 
         else:
             row.remove_marker(current_marker)
             if not row.has_markers():
                 del self._dm_rows[current_marker.id]
-                self._list_box.remove(row)
+                self._remove_row(row)
 
     def _add_or_update_displayed_marker_row(
         self, timestamp: datetime, markers: list[DisplayedMarkerData]
     ) -> DisplayedRow | None:
-
         displayed_id = markers[0].id
         row = self._dm_rows.get(displayed_id)
         if row is not None:
@@ -799,9 +805,6 @@ class ConversationView(Gtk.ScrolledWindow):
             row.set_merged(merge)
             return
 
-    def _on_remove_row(self, row: BaseRow) -> None:
-        self._list_box.remove(row)
-
     def _on_message_row_state_flags_changed(
         self, row: MessageRow, previous_flags: Gtk.StateFlags
     ) -> None:
@@ -822,7 +825,11 @@ class ConversationView(Gtk.ScrolledWindow):
         if previous_flags & Gtk.StateFlags.PRELIGHT:
             self._message_row_actions.hide_actions()
         else:
-            success, point = row.compute_point(self, Graphene.Point.zero())
+            try:
+                success, point = row.compute_point(self, Graphene.Point.zero())
+            except GLib.Error:
+                return
+
             if not success:
                 return
 
@@ -835,7 +842,7 @@ class ConversationView(Gtk.ScrolledWindow):
 
         self._remove_from_maps(row)
         index = row.get_index()
-        self._list_box.remove(row)
+        self._remove_row(row)
         decendant_row = self._list_box.get_row_at_index(index)
         if isinstance(decendant_row, MessageRow):
             # Unset possible merged state if we delete a 'top level' message.
@@ -905,7 +912,6 @@ class ConversationView(Gtk.ScrolledWindow):
     def _get_message_row_by_direction(
         self, pk: int, direction: Direction | None = None
     ) -> MessageRow | None:
-
         row = self.get_row_by_pk(pk)
         if row is None:
             return None
@@ -949,10 +955,14 @@ class ConversationView(Gtk.ScrolledWindow):
     def iter_rows(self) -> Generator[BaseRow, None, None]:
         yield from cast(list[BaseRow], iterate_listbox_children(self._list_box))
 
+    def _remove_row(self, row: BaseRow) -> None:
+        check_finalize(row)
+        self._list_box.remove(row)
+
     def _remove_rows_by_type(self, row_type: str) -> None:
         for row in self.iter_rows():
             if row.type == row_type:
-                self._list_box.remove(row)
+                self._remove_row(row)
 
     def update_call_rows(self) -> None:
         for row in cast(list[BaseRow], iterate_listbox_children(self._list_box)):
@@ -1020,7 +1030,6 @@ class ConversationView(Gtk.ScrolledWindow):
     def _on_contact_setting_changed(
         self, value: Any, setting: str, _account: str | None, _jid: JID | None
     ) -> None:
-
         if setting == "print_join_left":
             if value:
                 return
