@@ -51,6 +51,7 @@ from gajim.gtk.chat_stack import ChatStack
 from gajim.gtk.const import MAIN_WIN_ACTIONS
 from gajim.gtk.emoji_chooser import EmojiChooser
 from gajim.gtk.main_stack import MainStack
+from gajim.gtk.preview.preview import PreviewWidget
 from gajim.gtk.start_chat import parse_uri
 from gajim.gtk.structs import AccountJidParam
 from gajim.gtk.structs import actionmethod
@@ -130,12 +131,6 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
         controller.connect("motion", self._on_window_motion_notify)
         self.add_controller(controller)
 
-        controller = Gtk.EventControllerKey(
-            propagation_phase=Gtk.PropagationPhase.BUBBLE
-        )
-        controller.connect("key-pressed", self._on_key_pressed)
-        self.add_controller(controller)
-
         self.register_events(
             [
                 ("message-received", ged.GUI1, self._on_message_received),
@@ -171,6 +166,9 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
                 "resume-successful", self._on_client_resume_successful
             )
 
+        manager = app.app.get_shortcut_manager()
+        manager.install_shortcuts(self, "main-win")
+
     @property
     def about_dialog(self) -> AboutDialog:
         assert self._about_dialog is not None
@@ -266,19 +264,6 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
         self._main_stack.remove_account_page(event.account)
         self._main_stack.remove_chats_for_account(event.account)
 
-    def _on_key_pressed(
-        self,
-        _event_controller_key: Gtk.EventControllerKey,
-        keyval: int,
-        _keycode: int,
-        state: Gdk.ModifierType,
-    ) -> bool:
-        if keyval == Gdk.KEY_space:
-            self.get_chat_stack().get_message_input().grab_focus()
-            return Gdk.EVENT_STOP
-
-        return Gdk.EVENT_PROPAGATE
-
     def _on_client_state_changed(
         self, client: Client, _signal_name: str, state: SimpleClientState
     ) -> None:
@@ -554,12 +539,12 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
         app_font_size = app.settings.get("app_font_size")
         new_app_font_size = app_font_size
         if action_name == "increase-app-font-size":
-            new_app_font_size = app_font_size + 0.125
+            new_app_font_size = app_font_size + 0.10
         elif action_name == "decrease-app-font-size":
-            new_app_font_size = app_font_size - 0.125
+            new_app_font_size = app_font_size - 0.10
 
         # Clamp font size
-        new_app_font_size = max(min(1.5, new_app_font_size), 1.0)
+        new_app_font_size = max(min(3.0, new_app_font_size), 0.5)
 
         if new_app_font_size == app_font_size:
             return
@@ -734,9 +719,12 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
 
     def _on_handle_uri(self, _action: Gio.SimpleAction, param: GLib.Variant) -> None:
         uris = param.unpack()
+        log.debug("Try to handle uris: %s", uris)
         if not uris:
             return
 
+        self.present()
+
         uri = parse_uri(uris[0])
         match uri:
             case XmppIri():
@@ -790,9 +778,8 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
             assert contact is not None
             client = app.get_client(contact.account)
             chat_stack = self._chat_page.get_chat_stack()
-            msg_action_box = chat_stack.get_message_action_box()
             client.get_module("Chatstate").set_mouse_activity(
-                contact, msg_action_box.msg_textview.has_text
+                contact, chat_stack.get_message_input().has_text
             )
 
     def _on_chat_selected(self, *args: Any) -> None:
@@ -809,7 +796,7 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
         elif action == "minimize":
             self.minimize()
         else:
-            self.quit()
+            app.app.start_shutdown()
 
         return Gdk.EVENT_STOP
 
@@ -846,15 +833,15 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
             return False
         return self._chat_page.is_chat_selected(account, jid)
 
-    def highlight_dnd_targets(self, drag_row: Any, highlight: bool) -> None:
-        if isinstance(drag_row, ChatListRow):
+    def highlight_dnd_targets(self, dragged_object: Any, highlight: bool) -> None:
+        if isinstance(dragged_object, ChatListRow | PreviewWidget):
             chat_list_stack = self._chat_page.get_chat_list_stack()
             workspace = self.get_active_workspace()
             if workspace is None:
                 return
 
-            if drag_row.is_pinned:
-                chat_list = chat_list_stack.get_chatlist(workspace)
+            chat_list = chat_list_stack.get_chatlist(workspace)
+            if isinstance(dragged_object, ChatListRow) and dragged_object.is_pinned:
                 for row in chat_list.get_chat_list_rows():
                     if not row.is_pinned:
                         continue
@@ -864,7 +851,14 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
                     else:
                         row.remove_css_class("dnd-target-chatlist")
 
-        self._app_side_bar.highlight_dnd_targets(highlight)
+            if isinstance(dragged_object, PreviewWidget):
+                for row in chat_list.get_chat_list_rows():
+                    if highlight:
+                        row.add_css_class("dnd-target-chatlist")
+                    else:
+                        row.remove_css_class("dnd-target-chatlist")
+
+        self._app_side_bar.highlight_dnd_targets(dragged_object, highlight)
 
     def _add_workspace(self, _action: Gio.SimpleAction, param: GLib.Variant) -> None:
         workspace_id = param.get_string()
@@ -1335,7 +1329,7 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
         if not self.chat_exists(event.account, event.jid):
             self.add_chat(event.account, event.jid, "chat")
 
-    def quit(self) -> None:
+    def start_shutdown(self) -> None:
         self.show_toast(Adw.Toast(title=_("Gajim is quitting…"), timeout=0))
 
         if self.is_visible():
@@ -1343,5 +1337,5 @@ class MainWindow(Adw.ApplicationWindow, EventHelper):
             app.settings.set("mainwin_width", window_width)
             app.settings.set("mainwin_height", window_height)
 
-        app.settings.save()
-        app.app.start_shutdown()
+    def reload_view(self, *args: Any) -> None:
+        self.get_control().get_conversation_view().reload()
